@@ -19,6 +19,7 @@ impl App {
     pub fn print_tasks(&self) {
         let total_tasks = self.db.total_tasks();
         let total_checked = self.db.total_checked();
+        let total_notes = self.db.total_notes();
 
         if total_tasks == 0 {
             ui::help_message();
@@ -48,7 +49,7 @@ impl App {
             ui::new_line();
         }
 
-        ui::footer(total_checked, total_tasks, 0);
+        ui::footer(total_checked, total_tasks, total_notes);
     }
     fn ids() -> Vec<usize> {
         let args: Vec<String> = std::env::args().skip(1).collect();
@@ -87,7 +88,7 @@ impl App {
             args.iter().flat_map(|arg| arg.parse::<usize>()).collect()
         }
     }
-    pub fn add_task(&self, is_note: bool, skip_command: bool) {
+    fn add(&self, is_note: bool, skip_command: bool) {
         let args = if skip_command { &ARGS[1..] } else { &ARGS };
         let mut board_name = None;
         let item = if args.len() >= 2 {
@@ -117,6 +118,15 @@ impl App {
             self.db.insert_task(&item, board_name);
         }
     }
+    fn add_task_short(&self) {
+        self.add(false, true)
+    }
+    fn add_task(&self) {
+        self.add(false, false);
+    }
+    fn add_note(&self) {
+        self.add(true, false);
+    }
     pub fn parse_args(&self) {
         match ARGS.len() {
             0 => {
@@ -148,16 +158,16 @@ impl App {
                         println!("t {}", env!("CARGO_PKG_VERSION"));
                         return;
                     }
-                    "a" => self.add_task(false, true),
+                    "a" => self.add_task(),
                     "d" => self.db.delete_tasks(&App::ids()),
                     "c" => self.db.check_tasks(&App::ids()),
                     "cls" => self.db.clear_tasks().unwrap(),
-                    "n" => self.add_task(true, true),
+                    "n" => self.add_note(),
                     _ => {
                         if numbers {
                             self.db.check_tasks(&App::ids());
                         } else {
-                            self.add_task(false, false);
+                            self.add_task_short();
                         }
                     }
                 };
